@@ -2,6 +2,5 @@ var _ogre_shader_ex_integrated_p_s_s_m3_8h =
 [
     [ "SGX_LIB_INTEGRATEDPSSM", "group___r_t_shader.html#gaef923817b4e357235b862cbea0147e2b", null ],
     [ "SGX_FUNC_COMPUTE_SHADOW_COLOUR3", "group___r_t_shader.html#ga78adec906ae28462e707fce51123b007", null ],
-    [ "SGX_FUNC_APPLYSHADOWFACTOR_DIFFUSE", "group___r_t_shader.html#ga8bc52c44d087e8e3fccfe6ac0f8228bc", null ],
-    [ "SGX_FUNC_MODULATE_SCALAR", "group___r_t_shader.html#gaade9c91c16c93db0254bdf873f12877d", null ]
+    [ "SGX_FUNC_APPLYSHADOWFACTOR_DIFFUSE", "group___r_t_shader.html#ga8bc52c44d087e8e3fccfe6ac0f8228bc", null ]
 ];
\ No newline at end of file
