@@ -1,6 +1,6 @@
 var _ogre_shader_ex_normal_map_lighting_8h =
 [
-    [ "SGX_LIB_NORMALMAPLIGHTING", "group___r_t_shader.html#gaa903156e76e7c76f38a047afbfb4a0f6", null ],
+    [ "SGX_LIB_NORMALMAP", "group___r_t_shader.html#ga4c3d15b79dd582053d00d9d7d47a32ad", null ],
     [ "SGX_FUNC_CONSTRUCT_TBNMATRIX", "group___r_t_shader.html#gae51eb16802a9207f0996b57d3c97ddc1", null ],
     [ "SGX_FUNC_FETCHNORMAL", "group___r_t_shader.html#gabbeda2f98f182b98f2342fe8a0c8609f", null ]
 ];
\ No newline at end of file
