@@ -8,7 +8,7 @@ var class_ogre_1_1_compositor_manager =
     [ "ResourceMapIterator", "class_ogre_1_1_compositor_manager.html#a4f7da59507a5a8550ea97615ff9afff0", null ],
     [ "CompositorManager", "class_ogre_1_1_compositor_manager.html#aeb2dde02f0631082a73fafcff189f3d7", null ],
     [ "~CompositorManager", "class_ogre_1_1_compositor_manager.html#ac758255395ad3b00bea001aa0aaf88d6", null ],
-    [ "createImpl", "class_ogre_1_1_compositor_manager.html#a080ccf8b0bc960851de3e714074ac306", null ],
+    [ "createImpl", "class_ogre_1_1_compositor_manager.html#a068f207f595f441bbba1886ba7a3e276", null ],
     [ "initialise", "class_ogre_1_1_compositor_manager.html#ae0f865406c64dfe73350cbeb04ce26e6", null ],
     [ "create", "class_ogre_1_1_compositor_manager.html#aa8e6e8df0d1413256a0b961fe929eab7", null ],
     [ "getByName", "class_ogre_1_1_compositor_manager.html#add867aa539ff9381028bfd59d06621c0", null ],
@@ -22,19 +22,16 @@ var class_ogre_1_1_compositor_manager =
     [ "_getTexturedRectangle2D", "class_ogre_1_1_compositor_manager.html#a0ecf753b0c5e5cd464ff2a94e53946fb", null ],
     [ "removeAll", "class_ogre_1_1_compositor_manager.html#a565f51a7a31bc6848c9e334d1c699242", null ],
     [ "_reconstructAllCompositorResources", "class_ogre_1_1_compositor_manager.html#a5cc7bae199f7984d34f725c7d0d255fb", null ],
-    [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#afe7b9029fce793297867b5bf2a982488", null ],
+    [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#af2bedc34a0d3195f0a2fc70e9b5705be", null ],
     [ "freePooledTextures", "class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf", null ],
     [ "registerCompositorLogic", "class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c", null ],
     [ "unregisterCompositorLogic", "class_ogre_1_1_compositor_manager.html#aa7da6f02251d1e14ee50dcb1591e391c", null ],
     [ "getCompositorLogic", "class_ogre_1_1_compositor_manager.html#a1c8ef4b27b89bcc2a2529dd6312fdab5", null ],
     [ "hasCompositorLogic", "class_ogre_1_1_compositor_manager.html#a25c528930841cdf825aa359850bd7788", null ],
-    [ "getHasCompositorLogic", "class_ogre_1_1_compositor_manager.html#ac15d348feb398c9768dda450a9f93bb9", null ],
     [ "registerCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ae9b8ca4c2a51c0720bb31393d20fe7c9", null ],
     [ "unregisterCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a7abff0df9bc7cdd96cb730f8baad7f04", null ],
-    [ "unRegisterCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#af6d4de920791ce1811bf7ada8b65e795", null ],
     [ "getCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a230ea1697d0760278ba5af8ea991c04e", null ],
     [ "hasCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ad41f67cec0ec695f3e29263de4003d2f", null ],
-    [ "getHasCompositionPass", "class_ogre_1_1_compositor_manager.html#a21415a9db2d17ab45ac03bd17f76cd47", null ],
     [ "_relocateChain", "class_ogre_1_1_compositor_manager.html#a31474f0e4d6485437c1cb856923d4499", null ],
     [ "getSingleton", "class_ogre_1_1_compositor_manager.html#a3c401a0186d115243eaef438450a0b17", null ],
     [ "getSingletonPtr", "class_ogre_1_1_compositor_manager.html#a087432078a26a4fe1c2068012f3300f3", null ],
