@@ -1,5 +1,6 @@
 var class_ogre_1_1_root =
 [
+    [ "MovableObjectFactoryMap", "class_ogre_1_1_root.html#aa63b41f580aca52c3f35279dd06234fc", null ],
     [ "PluginLibList", "class_ogre_1_1_root.html#a33f7c5af7a51aff1d28a8d7f16253d57", null ],
     [ "PluginInstanceList", "class_ogre_1_1_root.html#a9bd411bb1456e55ca634a67ef003e691", null ],
     [ "MovableObjectFactoryIterator", "class_ogre_1_1_root.html#a724ee7dcbdb7b8052420df2fecd07c0d", null ],
@@ -85,6 +86,7 @@ var class_ogre_1_1_root =
     [ "hasMovableObjectFactory", "class_ogre_1_1_root.html#a90c3f8c5e515282b8aa0fe0352ddc934", null ],
     [ "getMovableObjectFactory", "class_ogre_1_1_root.html#ab89302520cbbe6d78d25e325081ea906", null ],
     [ "_allocateNextMovableObjectTypeFlag", "class_ogre_1_1_root.html#a3840c316ccddef1ccadf51325ad72ee2", null ],
+    [ "getMovableObjectFactories", "class_ogre_1_1_root.html#aac9810b87f46b33844f4d55828cb74fc", null ],
     [ "getMovableObjectFactoryIterator", "class_ogre_1_1_root.html#a18d21240d53ca480b6c122d80185ac3b", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_root.html#a14e8da7f3396ba7d22940006c6cba55d", null ],
     [ "getWorkQueue", "class_ogre_1_1_root.html#aadb91b200119d99eac7db174424f6634", null ],
