@@ -391,6 +391,8 @@ var group___terrain =
       [ "defineTerrain", "class_ogre_1_1_terrain_group.html#a212c614fe05a4c09731b3c2d9227d1e2", null ],
       [ "loadAllTerrains", "class_ogre_1_1_terrain_group.html#ad1666853bba30ba6c5d98a5f2fc7d7ad", null ],
       [ "loadTerrain", "class_ogre_1_1_terrain_group.html#aa2b3aa6c682d8b60be016bc6e503bd3b", null ],
+      [ "loadLegacyTerrain", "class_ogre_1_1_terrain_group.html#a5d53c0a3858a5bafe5b4b0109dfd585c", null ],
+      [ "loadLegacyTerrain", "class_ogre_1_1_terrain_group.html#a1f745bc5408998dde991f619fde76611", null ],
       [ "unloadTerrain", "class_ogre_1_1_terrain_group.html#afce782965e3d453f9ceb97ae95780e6f", null ],
       [ "removeTerrain", "class_ogre_1_1_terrain_group.html#ac61b66e483e66bf0c860b6d9885aa5dd", null ],
       [ "removeAllTerrains", "class_ogre_1_1_terrain_group.html#afdf092661bbf77ba7e1d5080f2f3bbe2", null ],
@@ -591,9 +593,6 @@ var group___terrain =
         [ "getReceiveDynamicShadowsDepth", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ad05e8720289fa690a7eb067ddf866ed1", null ],
         [ "setReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ac0d80ec80ca2029cdc7b53181998967e", null ],
         [ "getReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#abdad895571b1c8eee7afb93ce3ed6568", null ],
-        [ "_isSM3Available", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#abea3ffc6510069640561514061727f8f", null ],
-        [ "_isSM4Available", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a0051802ee822593363240bc9dd95adc3", null ],
-        [ "_getShaderLanguage", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a6d1da5f921c890b5a1b1d74037db8f38", null ],
         [ "isShadowingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a3ee1366c733ac203bb789983ab45c63a", null ],
         [ "getParent", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a008853c9b897c24b0cc23b7037ce4200", null ],
         [ "getName", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a871250453438cb71b42d1e907bd850f4", null ],
